@@ -4,8 +4,12 @@ package Net::FattureInCloud {
     use Carp qw/croak confess/;
     use List::Util qw/first/;
     use Mojo::Util qw/url_escape url_unescape/;
+    use namespace::clean;
+    use version;
     use v5.36;
 
+    our $VERSION = qv("v0.1.1");
+
     has endpoint_uri => ( is => 'ro', default => sub { 'https://api-v2.fattureincloud.it/' } );
     has token => ( is => 'ro' );
     has company_id => ( is => 'ro' );
@@ -86,4 +90,4 @@ Michele Beltrame, C<mb@blendgroup.it>
 
 This library is free software under the Artistic License 2.0.
 
-=cut
\ No newline at end of file
+=cut
